@@ -2,6 +2,7 @@ require 'spec_helper'
 require 'support/time'
 require 'stringio'
 
+# rubocop:disable Layout/LineContinuationLeadingSpace
 class    ProgressBar
 describe Base do
   let(:output) do
@@ -190,7 +191,8 @@ describe Base do
       progressbar       = ProgressBar::Base.new(:output => output, :autostart => false)
       progressbar.total = 0
 
-      expect { progressbar.start }.not_to raise_error
+      expect { progressbar.start }.
+        not_to raise_error
     end
   end
 
@@ -226,6 +228,42 @@ describe Base do
       expect(output_string).to start_with("                    \r")
     end
 
+    it 'displays the completed wall clock time if the progress is finished' do
+      Timecop.freeze(::Time.utc(2020, 1, 1, 0, 0, 0))
+
+      progressbar = ProgressBar::Base.new(:output    => output,
+                                          :projector => { :strength => 0.0 },
+                                          :total     => 100,
+                                          :format    => '%l')
+
+      progressbar.progress += 50
+
+      Timecop.freeze(::Time.utc(2020, 1, 1, 0, 30, 0))
+
+      progressbar.finish
+
+      Timecop.return
+
+      expect(progressbar.to_s).to eql '00:30:00'
+    end
+
+    it 'displays the estimated wall clock time if the progress is ongoing' do
+      Timecop.freeze(::Time.utc(2020, 1, 1, 0, 0, 0))
+
+      progressbar = ProgressBar::Base.new(:output    => output,
+                                          :projector => { :strength => 0.0 },
+                                          :total     => 100,
+                                          :format    => '%l')
+
+      progressbar.progress += 50
+
+      Timecop.freeze(::Time.utc(2020, 1, 1, 0, 30, 0))
+
+      expect(progressbar.to_s).to eql '01:00:00'
+
+      Timecop.return
+    end
+
     it 'does not error if there is nothing to do and it has not been started' do
       progressbar = ProgressBar::Base.new(:started_at => 0,
                                           :total      => 0,
@@ -233,9 +271,36 @@ describe Base do
                                           :format     => ' %c/%C |%w>%i| %e ',
                                           :output     => output)
 
-      expect { progressbar.stop }.not_to raise_error
+      expect { progressbar.stop }.
+        not_to raise_error
     end
 
+    # rubocop:disable RSpec/AnyInstance
+    it 'displays a warning if the user passes the deprecated "smoothing" option but ' \
+       'still processes it' do
+      expect_any_instance_of(ProgressBar::Base).
+        to receive(:warn).
+        with(include("WARNING: Passing the 'smoothing' option is deprecated"))
+
+      Timecop.freeze(::Time.utc(2020, 1, 1, 0, 0, 0))
+
+      progressbar = ProgressBar::Base.new(:output    => output,
+                                          :smoothing => 0.0,
+                                          :total     => 100,
+                                          :format    => '%l')
+
+      progressbar.progress += 50
+
+      Timecop.freeze(::Time.utc(2020, 1, 1, 0, 30, 0))
+
+      progressbar.finish
+
+      Timecop.return
+
+      expect(progressbar.to_s).to eql '00:30:00'
+    end
+    # rubocop:enable RSpec/AnyInstance
+
     it 'appends proper ending to string for non-TTY devices' do
       progressbar = ProgressBar::Base.new(:output => non_tty_output)
 
@@ -414,6 +479,18 @@ describe Base do
 
       expect(progressbar.to_s).to eql ' ETA: ??:??:??'
     end
+
+    it 'displays the unknown wall clock time' do
+      progressbar = ProgressBar::Base.new(:output => output,
+                                          :total  => 100,
+                                          :format => '%l')
+
+      progressbar.progress += 10
+      progressbar.reset
+      progressbar.progress += 10
+
+      expect(progressbar.to_s).to eql '--:--:--'
+    end
   end
 
   context 'when logging messages' do
@@ -554,7 +631,9 @@ describe Base do
     end
   end
 
-  it 'can be converted into a hash', :time_mock => ::Time.utc(2012, 7, 26, 18, 0, 0) do
+  it 'can be converted into a hash' do
+    ::Timecop.freeze(::Time.utc(2012, 7, 26, 18, 0, 0))
+
     progressbar = ProgressBar::Base.new(:output         => output,
                                         :total          => 33,
                                         :title          => 'My Title',
@@ -595,6 +674,9 @@ describe Base do
         'stopped?'                            => false,
         'finished?'                           => false
     )
+
+    ::Timecop.return
   end
 end
 end
+# rubocop:enable Layout/LineContinuationLeadingSpace
