@@ -138,7 +138,7 @@ describe Formatter do
     end
 
     it 'is the estimated time remaining when called after the bar is started' do
-      progressbar = ProgressBar::Base.new(:smoothing => 0.0)
+      progressbar = ProgressBar::Base.new(:projector => { :strength => 0.0 })
 
       Timecop.freeze(to_the_past) do
         progressbar.start
@@ -149,7 +149,8 @@ describe Formatter do
     end
 
     it 'is "??:??:??" when it could take 100 hours or longer to finish' do
-      progressbar = ProgressBar::Base.new(:total => 100, :smoothing => 0.0)
+      progressbar = ProgressBar::Base.new(:total     => 100,
+                                          :projector => { :strength => 0.0 })
 
       Timecop.freeze(one_hundred_hours_ago) do
         progressbar.start
@@ -174,6 +175,64 @@ describe Formatter do
     end
   end
 
+  context 'with the %l flag' do
+    let(:format) { Format::String.new('%l') }
+
+    it 'is unknown estimated time when called before the bar is started' do
+      progressbar = ProgressBar::Base.new
+
+      expect(Formatter.process(format, 100, progressbar)).to eql '--:--:--'
+    end
+
+    it 'is unknown estimated time when the bar is started with any progress' do
+      progressbar = ProgressBar::Base.new(:starting_at =>  1)
+
+      expect(Formatter.process(format, 100, progressbar)).to eql '--:--:--'
+    end
+
+    it 'is "--:--:--" when called after the bar is started makes progress and reset' do
+      progressbar = ProgressBar::Base.new
+
+      Timecop.freeze(to_the_past) do
+        progressbar.start
+        progressbar.progress = 50
+      end
+
+      progressbar.reset
+
+      expect(Formatter.process(format, 100, progressbar)).to eql '--:--:--'
+    end
+
+    it 'is the estimated wall clock time when called after the bar is started' do
+      progressbar = nil
+
+      Timecop.freeze(::Time.utc(2020, 1, 1, 0, 0, 0)) do
+        progressbar = ProgressBar::Base.new(:projector => { :strength => 0.0 })
+
+        progressbar.start
+        progressbar.progress = 50
+      end
+
+      Timecop.freeze(::Time.utc(2020, 1, 1, 0, 10, 0)) do
+        expect(Formatter.process(format, 100, progressbar)).to eql '00:20:00'
+      end
+    end
+
+    it 'is completed wall clock time once the bar finishes' do
+      progressbar = ProgressBar::Base.new(:throttle_rate => 0.0)
+
+      Timecop.freeze(::Time.utc(2020, 1, 1, 0, 10, 0)) do
+        progressbar.start
+      end
+
+      Timecop.freeze(::Time.utc(2020, 1, 1, 0, 7, 0)) do
+        progressbar.finish
+      end
+
+      expect(Formatter.process(format, 100, progressbar)).to eql '00:07:00'
+    end
+  end
+
   context 'with the %E flag' do
     let(:format) { Format::String.new('%E') }
 
@@ -203,7 +262,7 @@ describe Formatter do
     end
 
     it 'is the estimated time remaining when called after the bar is started' do
-      progressbar = ProgressBar::Base.new(:smoothing => 0.0)
+      progressbar = ProgressBar::Base.new(:projector => { :strength => 0.0 })
 
       Timecop.freeze(to_the_past) do
         progressbar.start
@@ -228,7 +287,8 @@ describe Formatter do
     end
 
     it 'is "> 4 Days" when it could take 100 hours or longer to finish' do
-      progressbar = ProgressBar::Base.new(:total => 100, :smoothing => 0.0)
+      progressbar = ProgressBar::Base.new(:total     => 100,
+                                          :projector => { :strength => 0.0 })
 
       Timecop.freeze(one_hundred_hours_ago) do
         progressbar.start
@@ -268,7 +328,7 @@ describe Formatter do
     end
 
     it 'is the estimated time remaining when called after the bar is started' do
-      progressbar = ProgressBar::Base.new(:smoothing => 0.0)
+      progressbar = ProgressBar::Base.new(:projector => { :strength => 0.0 })
 
       Timecop.freeze(to_the_past) do
         progressbar.start
@@ -279,7 +339,8 @@ describe Formatter do
     end
 
     it 'is the exact estimated time when it could take 100 hours or longer to finish' do
-      progressbar = ProgressBar::Base.new(:total => 100, :smoothing => 0.0)
+      progressbar = ProgressBar::Base.new(:total     => 100,
+                                          :projector => { :strength => 0.0 })
 
       Timecop.freeze(one_hundred_hours_ago) do
         progressbar.start
@@ -714,8 +775,8 @@ describe Formatter do
     end
 
     it 'is an empty bar when the terminal width is shorter than the string ' \
-        'being output and the full bar length is calculated (but lacks the ' \
-        'space to output the entire bar)' do
+       'being output and the full bar length is calculated (but lacks the ' \
+       'space to output the entire bar)' do
       format      = Format::String.new('%t%B')
       progressbar = ProgressBar::Base.new(:title     => ('*' * 19),
                                           :autostart => false)
@@ -724,8 +785,8 @@ describe Formatter do
     end
 
     it 'is an empty bar when the terminal width is shorter than the string ' \
-        'being output and the combination of bar and incomplete length is ' \
-        'calculated (but lacks the space to output the entire bar)' do
+       'being output and the combination of bar and incomplete length is ' \
+       'calculated (but lacks the space to output the entire bar)' do
       format      = Format::String.new('%t%w%i')
       progressbar = ProgressBar::Base.new(:title     => ('*' * 19),
                                           :autostart => false)
