@@ -3,7 +3,7 @@ module WarningFilter
     def initialize(io)
       @io = io
 
-      super()
+      super(File::RDONLY | File::WRONLY)
     end
 
     def write(line)
@@ -28,4 +28,4 @@ module WarningFilter
   end
 end
 
-$stderr = ::WarningFilter::Filter.new($stderr)
+$stderr = WarningFilter::Filter.new($stderr)
